@@ -1,4 +1,4 @@
-from __init__ import v, sqrt, nsqrt
+from units_python.__init__ import v, sqrt, nsqrt
 
 def run_tests():
 
